@@ -4,16 +4,16 @@
 # Python module.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
 
 # Create an new Excel file and add a worksheet.
-workbook = xlsxwriter.Workbook('background.xlsx')
+workbook = xlsxwriter.Workbook("background.xlsx")
 worksheet = workbook.add_worksheet()
 
 # Set the background image.
-worksheet.set_background('logo.png')
+worksheet.set_background("logo.png")
 
 workbook.close()
