@@ -3,15 +3,15 @@
 # An example of a simple Excel chart with Python and XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
-workbook = xlsxwriter.Workbook('chart.xlsx')
+workbook = xlsxwriter.Workbook("chart.xlsx")
 worksheet = workbook.add_worksheet()
 
 # Create a new Chart object.
-chart = workbook.add_chart({'type': 'column'})
+chart = workbook.add_chart({"type": "column"})
 
 # Write some data to add to plot on the chart.
 data = [
@@ -20,16 +20,16 @@ data = [
     [3, 6, 9, 12, 15],
 ]
 
-worksheet.write_column('A1', data[0])
-worksheet.write_column('B1', data[1])
-worksheet.write_column('C1', data[2])
+worksheet.write_column("A1", data[0])
+worksheet.write_column("B1", data[1])
+worksheet.write_column("C1", data[2])
 
 # Configure the charts. In simplest case we just add some data series.
-chart.add_series({'values': '=Sheet1!$A$1:$A$5'})
-chart.add_series({'values': '=Sheet1!$B$1:$B$5'})
-chart.add_series({'values': '=Sheet1!$C$1:$C$5'})
+chart.add_series({"values": "=Sheet1!$A$1:$A$5"})
+chart.add_series({"values": "=Sheet1!$B$1:$B$5"})
+chart.add_series({"values": "=Sheet1!$C$1:$C$5"})
 
 # Insert the chart into the worksheet.
-worksheet.insert_chart('A7', chart)
+worksheet.insert_chart("A7", chart)
 
 workbook.close()
