@@ -3,32 +3,32 @@
 # A simple example of some of the features of the XlsxWriter Python module.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
 
 # Create an new Excel file and add a worksheet.
-workbook = xlsxwriter.Workbook('demo.xlsx')
+workbook = xlsxwriter.Workbook("demo.xlsx")
 worksheet = workbook.add_worksheet()
 
 # Widen the first column to make the text clearer.
-worksheet.set_column('A:A', 20)
+worksheet.set_column("A:A", 20)
 
 # Add a bold format to use to highlight cells.
-bold = workbook.add_format({'bold': True})
+bold = workbook.add_format({"bold": True})
 
 # Write some simple text.
-worksheet.write('A1', 'Hello')
+worksheet.write("A1", "Hello")
 
 # Text with formatting.
-worksheet.write('A2', 'World', bold)
+worksheet.write("A2", "World", bold)
 
 # Write some numbers, with row/column notation.
 worksheet.write(2, 0, 123)
 worksheet.write(3, 0, 123.456)
 
 # Insert an image.
-worksheet.insert_image('B5', 'logo.png')
+worksheet.insert_image("B5", "logo.png")
 
 workbook.close()
