@@ -4,7 +4,7 @@
 # worksheet using the XlsxWriter module.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from io import BytesIO
@@ -14,32 +14,34 @@ from urllib.request import urlopen
 import xlsxwriter
 
 # Create the workbook and add a worksheet.
-workbook  = xlsxwriter.Workbook('images_bytesio.xlsx')
+workbook = xlsxwriter.Workbook("images_bytesio.xlsx")
 worksheet = workbook.add_worksheet()
 
 
 # Read an image from a remote url.
-url = 'https://raw.githubusercontent.com/jmcnamara/XlsxWriter/' + \
-      'master/examples/logo.png'
+url = (
+    "https://raw.githubusercontent.com/jmcnamara/XlsxWriter/"
+    + "master/examples/logo.png"
+)
 
 image_data = BytesIO(urlopen(url).read())
 
 # Write the byte stream image to a cell. Note, the filename must be
 # specified. In this case it will be read from url string.
-worksheet.insert_image('B2', url, {'image_data': image_data})
+worksheet.insert_image("B2", url, {"image_data": image_data})
 
 
 # Read a local image file into a a byte stream. Note, the insert_image()
 # method can do this directly. This is for illustration purposes only.
-filename   = 'python.png'
+filename = "python.png"
 
-image_file = open(filename, 'rb')
+image_file = open(filename, "rb")
 image_data = BytesIO(image_file.read())
 image_file.close()
 
 
 # Write the byte stream image to a cell. The filename must  be specified.
-worksheet.insert_image('B8', filename, {'image_data': image_data})
+worksheet.insert_image("B8", filename, {"image_data": image_data})
 
 
 workbook.close()
