@@ -4,11 +4,12 @@
 # method.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 import uuid
 
+
 # Create a function that will behave like a worksheet write() method.
 #
 # This function takes a UUID and writes it as as string. It should take the
@@ -19,20 +20,21 @@ import uuid
 def write_uuid(worksheet, row, col, token, format=None):
     return worksheet.write_string(row, col, str(token), format)
 
+
 # Set up the workbook as usual.
-workbook = xlsxwriter.Workbook('user_types1.xlsx')
+workbook = xlsxwriter.Workbook("user_types1.xlsx")
 worksheet = workbook.add_worksheet()
 
 # Make the first column wider for clarity.
-worksheet.set_column('A:A', 40)
+worksheet.set_column("A:A", 40)
 
 # Add the write() handler/callback to the worksheet.
 worksheet.add_write_handler(uuid.UUID, write_uuid)
 
 # Create a UUID.
-my_uuid = uuid.uuid3(uuid.NAMESPACE_DNS, 'python.org')
+my_uuid = uuid.uuid3(uuid.NAMESPACE_DNS, "python.org")
 
 # Write the UUID. This would raise a TypeError without the handler.
-worksheet.write('A1', my_uuid)
+worksheet.write("A1", my_uuid)
 
 workbook.close()
