@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("background06.xlsx")
 
-        self.set_filename('background06.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageSetup']}
+        self.ignore_elements = {"xl/worksheets/sheet1.xml": ["<pageSetup"]}
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with a background image."""
@@ -29,11 +28,10 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_image('E9', self.image_dir + 'logo.jpg')
-        worksheet.set_background(self.image_dir + 'logo.jpg')
+        worksheet.insert_image("E9", self.image_dir + "logo.jpg")
+        worksheet.set_background(self.image_dir + "logo.jpg")
 
-        worksheet.set_header('&C&G',
-                             {'image_center': self.image_dir + 'blue.jpg'})
+        worksheet.set_header("&C&G", {"image_center": self.image_dir + "blue.jpg"})
 
         workbook.close()
 
