@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("chart_area04.xlsx")
 
-        self.set_filename('chart_area04.xlsx')
-
-        self.ignore_elements = {'xl/workbook.xml': ['<fileVersion', '<calcPr']}
+        self.ignore_elements = {"xl/workbook.xml": ["<fileVersion", "<calcPr"]}
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -28,7 +27,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'area'})
+        chart = workbook.add_chart({"type": "area"})
 
         chart.axis_ids = [63591168, 63592704]
         chart.axis2_ids = [74921856, 73764224]
@@ -38,13 +37,13 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [6, 8, 6, 4, 2],
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
 
-        chart.add_series({'values': '=Sheet1!$A$1:$A$5'})
-        chart.add_series({'values': '=Sheet1!$B$1:$B$5', 'y2_axis': 1})
+        chart.add_series({"values": "=Sheet1!$A$1:$A$5"})
+        chart.add_series({"values": "=Sheet1!$B$1:$B$5", "y2_axis": 1})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
