@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,16 +17,15 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_column05.xlsx')
+        self.set_filename("chart_column05.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
 
         workbook = Workbook(self.got_filename)
 
-        worksheet = workbook.add_worksheet('Foo')
-        chart = workbook.add_chart({'type': 'column'})
+        worksheet = workbook.add_worksheet("Foo")
+        chart = workbook.add_chart({"type": "column"})
 
         chart.axis_ids = [47292800, 47295104]
 
@@ -34,18 +33,17 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [1, 2, 3, 4, 5],
             [2, 4, 6, 8, 10],
             [3, 6, 9, 12, 15],
-
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({'values': '=Foo!$A$1:$A$5'})
-        chart.add_series({'values': '=Foo!$B$1:$B$5'})
-        chart.add_series({'values': '=Foo!$C$1:$C$5'})
+        chart.add_series({"values": "=Foo!$A$1:$A$5"})
+        chart.add_series({"values": "=Foo!$B$1:$B$5"})
+        chart.add_series({"values": "=Foo!$C$1:$C$5"})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
