@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_column08.xlsx')
+        self.set_filename("chart_column08.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -26,7 +25,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'column'})
+        chart = workbook.add_chart({"type": "column"})
 
         chart.axis_ids = [68809856, 68811392]
 
@@ -34,21 +33,22 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [1, 2, 3, 4, 5],
             [2, 4, 6, 8, 10],
             [3, 6, 9, 12, 15],
-
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({
-            'categories': '=(Sheet1!$A$1:$A$2,Sheet1!$A$4:$A$5)',
-            'values': '=(Sheet1!$B$1:$B$2,Sheet1!$B$4:$B$5)',
-            'categories_data': [1, 2, 4, 5],
-            'values_data': [2, 4, 8, 10],
-        })
+        chart.add_series(
+            {
+                "categories": "=(Sheet1!$A$1:$A$2,Sheet1!$A$4:$A$5)",
+                "values": "=(Sheet1!$B$1:$B$2,Sheet1!$B$4:$B$5)",
+                "categories_data": [1, 2, 4, 5],
+                "values_data": [2, 4, 8, 10],
+            }
+        )
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
