@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("chart_combined03.xlsx")
 
-        self.set_filename('chart_combined03.xlsx')
-
-        self.ignore_elements = {'xl/charts/chart1.xml': ['<c:dispBlanksAs']}
+        self.ignore_elements = {"xl/charts/chart1.xml": ["<c:dispBlanksAs"]}
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -28,28 +27,27 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart1 = workbook.add_chart({'type': 'column'})
-        chart2 = workbook.add_chart({'type': 'line'})
+        chart1 = workbook.add_chart({"type": "column"})
+        chart2 = workbook.add_chart({"type": "line"})
 
         data = [
             [2, 7, 3, 6, 2],
             [20, 25, 10, 10, 20],
             [4, 2, 5, 2, 1],
-
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart1.add_series({'values': '=Sheet1!$A$1:$A$5'})
-        chart1.add_series({'values': '=Sheet1!$B$1:$B$5'})
+        chart1.add_series({"values": "=Sheet1!$A$1:$A$5"})
+        chart1.add_series({"values": "=Sheet1!$B$1:$B$5"})
 
-        chart2.add_series({'values': '=Sheet1!$C$1:$C$5'})
+        chart2.add_series({"values": "=Sheet1!$C$1:$C$5"})
 
         chart1.combine(chart2)
 
-        worksheet.insert_chart('E9', chart1)
+        worksheet.insert_chart("E9", chart1)
 
         workbook.close()
 
