@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_gradient02.xlsx')
+        self.set_filename("chart_gradient02.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -26,7 +25,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'column'})
+        chart = workbook.add_chart({"type": "column"})
 
         chart.axis_ids = [61363328, 61364864]
 
@@ -36,20 +35,21 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [3, 6, 9, 12, 15],
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({
-            'values': '=Sheet1!$A$1:$A$5',
-            'gradient': {'colors': ['#DDEBCF', '#9CB86E', '#156B13'],
-                         'angle': 30}
-        })
+        chart.add_series(
+            {
+                "values": "=Sheet1!$A$1:$A$5",
+                "gradient": {"colors": ["#DDEBCF", "#9CB86E", "#156B13"], "angle": 30},
+            }
+        )
 
-        chart.add_series({'values': '=Sheet1!$B$1:$B$5'})
-        chart.add_series({'values': '=Sheet1!$C$1:$C$5'})
+        chart.add_series({"values": "=Sheet1!$B$1:$B$5"})
+        chart.add_series({"values": "=Sheet1!$C$1:$C$5"})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
