@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_pie03.xlsx')
+        self.set_filename("chart_pie03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -26,24 +25,26 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'pie'})
+        chart = workbook.add_chart({"type": "pie"})
 
         data = [
             [2, 4, 6],
             [60, 30, 10],
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$3',
-            'values': '=Sheet1!$B$1:$B$3',
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$3",
+                "values": "=Sheet1!$B$1:$B$3",
+            }
+        )
 
-        chart.set_legend({'delete_series': [1]})
+        chart.set_legend({"delete_series": [1]})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
