@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_str02.xlsx')
+        self.set_filename("chart_str02.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file when the chart data contains strings."""
@@ -26,31 +25,34 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'scatter'})
+        chart = workbook.add_chart({"type": "scatter"})
 
         chart.axis_ids = [41671680, 41669376]
 
         data = [
-            [1, 2, 'Foo', 4, 5],
-            [2, 4, 'Bar', 8, 10],
-            [3, 6, 'Baz', 12, 15],
-
+            [1, 2, "Foo", 4, 5],
+            [2, 4, "Bar", 8, 10],
+            [3, 6, "Baz", 12, 15],
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$B$1:$B$5',
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$B$1:$B$5",
+            }
+        )
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$C$1:$C$5',
-        })
-        worksheet.insert_chart('E9', chart)
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$C$1:$C$5",
+            }
+        )
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
