@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('comment06.xlsx')
+        self.set_filename("comment06.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with comments."""
@@ -27,13 +26,13 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write_comment('A1', 'Some text')
-        worksheet.write_comment('A2', 'Some text')
-        worksheet.write_comment('A3', 'Some text', {'visible': True})
-        worksheet.write_comment('A4', 'Some text')
-        worksheet.write_comment('A5', 'Some text')
+        worksheet.write_comment("A1", "Some text")
+        worksheet.write_comment("A2", "Some text")
+        worksheet.write_comment("A3", "Some text", {"visible": True})
+        worksheet.write_comment("A4", "Some text")
+        worksheet.write_comment("A5", "Some text")
 
-        worksheet.set_comments_author('John')
+        worksheet.set_comments_author("John")
 
         workbook.close()
 
