@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('cond_format05.xlsx')
+        self.set_filename("cond_format05.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with conditional formatting."""
@@ -27,19 +26,22 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        format1 = workbook.add_format({'border': 1})
+        format1 = workbook.add_format({"border": 1})
 
-        worksheet.write('A1', 10)
-        worksheet.write('A2', 20)
-        worksheet.write('A3', 30)
-        worksheet.write('A4', 40)
+        worksheet.write("A1", 10)
+        worksheet.write("A2", 20)
+        worksheet.write("A3", 30)
+        worksheet.write("A4", 40)
 
-        worksheet.conditional_format('A1',
-                                     {'type': 'cell',
-                                      'format': format1,
-                                      'criteria': '==',
-                                      'value': 7,
-                                      })
+        worksheet.conditional_format(
+            "A1",
+            {
+                "type": "cell",
+                "format": format1,
+                "criteria": "==",
+                "value": 7,
+            },
+        )
 
         workbook.close()
 
