@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('cond_format14.xlsx')
+        self.set_filename("cond_format14.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with conditional formatting."""
@@ -27,20 +26,23 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        cell_format = workbook.add_format({'bg_color': 'red'})
+        cell_format = workbook.add_format({"bg_color": "red"})
 
-        worksheet.write('A1', 10)
-        worksheet.write('A2', 20)
-        worksheet.write('A3', 30)
-        worksheet.write('A4', 40)
+        worksheet.write("A1", 10)
+        worksheet.write("A2", 20)
+        worksheet.write("A3", 30)
+        worksheet.write("A4", 40)
 
-        worksheet.conditional_format('A1',
-                                     {'type': 'cell',
-                                      'format': cell_format,
-                                      'criteria': '>',
-                                      'value': 5,
-                                      'stop_if_true': True
-                                      })
+        worksheet.conditional_format(
+            "A1",
+            {
+                "type": "cell",
+                "format": cell_format,
+                "criteria": ">",
+                "value": 5,
+                "stop_if_true": True,
+            },
+        )
 
         workbook.close()
 
