@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('data_validation01.xlsx')
+        self.set_filename("data_validation01.xlsx")
 
     def test_create_file(self):
         """Test the creation of a XlsxWriter file with data validation."""
@@ -28,9 +27,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet = workbook.add_worksheet()
 
         worksheet.data_validation(
-            'C2', {'validate': 'list',
-                   'value': ['Foo', 'Bar', 'Baz'],
-                   }
+            "C2",
+            {
+                "validate": "list",
+                "value": ["Foo", "Bar", "Baz"],
+            },
         )
 
         workbook.close()
