@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('dynamic_array01.xlsx')
+        self.set_filename("dynamic_array01.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,9 +26,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write_dynamic_array_formula('A1:A1', '=AVERAGE(TIMEVALUE(B1:B2))', None, 0)
-        worksheet.write('B1', '12:00')
-        worksheet.write('B2', '12:00')
+        worksheet.write_dynamic_array_formula(
+            "A1:A1", "=AVERAGE(TIMEVALUE(B1:B2))", None, 0
+        )
+        worksheet.write("B1", "12:00")
+        worksheet.write("B2", "12:00")
 
         workbook.close()
 
