@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,27 +17,30 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("excel2003_style02.xlsx")
 
-        self.set_filename('excel2003_style02.xlsx')
-
-        self.ignore_files = ['xl/printerSettings/printerSettings1.bin',
-                             'xl/worksheets/_rels/sheet1.xml.rels']
-        self.ignore_elements = {'[Content_Types].xml': ['<Default Extension="bin"'],
-                                'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_files = [
+            "xl/printerSettings/printerSettings1.bin",
+            "xl/worksheets/_rels/sheet1.xml.rels",
+        ]
+        self.ignore_elements = {
+            "[Content_Types].xml": ['<Default Extension="bin"'],
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"],
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
 
-        workbook = Workbook(self.got_filename, {'excel2003_style': True})
+        workbook = Workbook(self.got_filename, {"excel2003_style": True})
 
         worksheet = workbook.add_worksheet()
 
         worksheet.set_paper(9)
 
-        bold = workbook.add_format({'bold': 1})
+        bold = workbook.add_format({"bold": 1})
 
-        worksheet.write('A1', 'Foo')
-        worksheet.write('A2', 'Bar', bold)
+        worksheet.write("A1", "Foo")
+        worksheet.write("A2", "Bar", bold)
 
         workbook.close()
 
