@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header03.xlsx")
 
-        self.set_filename('header03.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"]
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -29,8 +30,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_footer('&L&P', {'scale_with_doc': False,
-                                      'align_with_margins': False})
+        worksheet.set_footer(
+            "&L&P", {"scale_with_doc": False, "align_with_margins": False}
+        )
 
         workbook.close()
 
