@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,11 +17,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header_image09.xlsx")
 
-        self.set_filename('header_image09.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
-                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"],
+            "xl/worksheets/sheet2.xml": ["<pageMargins", "<pageSetup"],
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -31,13 +32,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet1 = workbook.add_worksheet()
         worksheet2 = workbook.add_worksheet()
 
-        worksheet1.write('A1', 'Foo')
-        worksheet1.write_comment('B2', 'Some text')
+        worksheet1.write("A1", "Foo")
+        worksheet1.write_comment("B2", "Some text")
 
-        worksheet1.set_comments_author('John')
+        worksheet1.set_comments_author("John")
 
-        worksheet2.set_header('&L&G',
-                              {'image_left': self.image_dir + 'red.jpg'})
+        worksheet2.set_header("&L&G", {"image_left": self.image_dir + "red.jpg"})
 
         workbook.close()
 
