@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header_image14.xlsx")
 
-        self.set_filename('header_image14.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"]
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -29,11 +30,14 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_header('&L&G&C&G&R&G',
-                             {'image_left': self.image_dir + 'black_72e.png',
-                              'image_center': self.image_dir + 'black_150e.png',
-                              'image_right': self.image_dir + 'black_300e.png',
-                              })
+        worksheet.set_header(
+            "&L&G&C&G&R&G",
+            {
+                "image_left": self.image_dir + "black_72e.png",
+                "image_center": self.image_dir + "black_150e.png",
+                "image_right": self.image_dir + "black_300e.png",
+            },
+        )
 
         workbook.close()
 
