@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('hyperlink11.xlsx')
+        self.set_filename("hyperlink11.xlsx")
 
     def test_link_format_explicit(self):
         """Test the creation of a simple XlsxWriter file with hyperlinks. This example has link formatting."""
@@ -26,9 +25,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        url_format = workbook.add_format({'color': 'blue', 'underline': 1})
+        url_format = workbook.add_format({"color": "blue", "underline": 1})
 
-        worksheet.write_url('A1', 'http://www.perl.org/', url_format)
+        worksheet.write_url("A1", "http://www.perl.org/", url_format)
 
         workbook.close()
 
