@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('hyperlink14.xlsx')
+        self.set_filename("hyperlink14.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with hyperlinks. This example has writes a url in a range."""
@@ -26,10 +25,14 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        format = workbook.add_format({'align': 'center'})
+        format = workbook.add_format({"align": "center"})
 
-        worksheet.merge_range('C4:E5', '', format,)
-        worksheet.write_url('C4', 'http://www.perl.org/', format, 'Perl Home')
+        worksheet.merge_range(
+            "C4:E5",
+            "",
+            format,
+        )
+        worksheet.write_url("C4", "http://www.perl.org/", format, "Perl Home")
 
         workbook.close()
 
