@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('hyperlink36.xlsx')
+        self.set_filename("hyperlink36.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -26,18 +25,18 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'pie'})
+        chart = workbook.add_chart({"type": "pie"})
 
-        worksheet.write('A1', 1)
-        worksheet.write('A2', 2)
+        worksheet.write("A1", 1)
+        worksheet.write("A2", 2)
 
-        worksheet.insert_image('E9',
-                               self.image_dir + 'red.png',
-                               {'url': 'https://github.com/jmcnamara'})
+        worksheet.insert_image(
+            "E9", self.image_dir + "red.png", {"url": "https://github.com/jmcnamara"}
+        )
 
-        chart.add_series({'values': '=Sheet1!$A$1:$A$2'})
+        chart.add_series({"values": "=Sheet1!$A$1:$A$2"})
 
-        worksheet.insert_chart('E12', chart)
+        worksheet.insert_chart("E12", chart)
 
         workbook.close()
 
