@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,18 +17,18 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('hyperlink44.xlsx')
+        self.set_filename("hyperlink44.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
 
         workbook = Workbook(self.got_filename)
 
-        worksheet = workbook.add_worksheet('Sheet 1')
+        worksheet = workbook.add_worksheet("Sheet 1")
 
-        worksheet.insert_image('E9', self.image_dir + 'red.png',
-                               {'url': "internal:'Sheet 1'!A1"})
+        worksheet.insert_image(
+            "E9", self.image_dir + "red.png", {"url": "internal:'Sheet 1'!A1"}
+        )
 
         workbook.close()
 
