@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2019, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('ignore_error04.xlsx')
+        self.set_filename("ignore_error04.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,11 +26,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write_string('A1', '123')
-        worksheet.write_string('C3', '123')
-        worksheet.write_string('E5', '123')
+        worksheet.write_string("A1", "123")
+        worksheet.write_string("C3", "123")
+        worksheet.write_string("E5", "123")
 
-        worksheet.ignore_errors({'number_stored_as_text': 'A1 C3 E5'})
+        worksheet.ignore_errors({"number_stored_as_text": "A1 C3 E5"})
 
         workbook.close()
 
