@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,15 +17,16 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('image42.xlsx')
+        self.set_filename("image42.xlsx")
 
         # Despite a lot of effort and testing I can't match Excel's
         # calculations exactly for EMF files. The differences are are small
         # (<1%) and in general aren't visible. The following ignore the
         # elements where these differences occur until the they can be
         # resolved. This issue doesn't occur for any other image type.
-        self.ignore_elements = {'xl/drawings/drawing1.xml': ['<xdr:rowOff>', '<xdr:colOff>', '<a:ext cx=']}
+        self.ignore_elements = {
+            "xl/drawings/drawing1.xml": ["<xdr:rowOff>", "<xdr:colOff>", "<a:ext cx="]
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -34,7 +35,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_image('E9', self.image_dir + 'test-000.emf')
+        worksheet.insert_image("E9", self.image_dir + "test-000.emf")
 
         workbook.close()
 
