@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('merge_range03.xlsx')
+        self.set_filename("merge_range03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,11 +26,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        format = workbook.add_format({'align': 'center'})
+        format = workbook.add_format({"align": "center"})
 
-        worksheet.merge_range(1, 1, 1, 2, 'Foo', format)
-        worksheet.merge_range(1, 3, 1, 4, 'Foo', format)
-        worksheet.merge_range(1, 5, 1, 6, 'Foo', format)
+        worksheet.merge_range(1, 1, 1, 2, "Foo", format)
+        worksheet.merge_range(1, 3, 1, 4, "Foo", format)
+        worksheet.merge_range(1, 5, 1, 6, "Foo", format)
 
         workbook.close()
 
