@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('object_position11.xlsx')
+        self.set_filename("object_position11.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with textbox(s)."""
@@ -27,10 +26,10 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_textbox('E9', 'This is some text', {'object_position': 4})
+        worksheet.insert_textbox("E9", "This is some text", {"object_position": 4})
 
-        worksheet.set_row(10, None, None, {'hidden': True})
-        worksheet.set_column('F:F', None, None, {'hidden': True})
+        worksheet.set_row(10, None, None, {"hidden": True})
+        worksheet.set_column("F:F", None, None, {"hidden": True})
 
         workbook.close()
 
