@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('protect05.xlsx')
+        self.set_filename("protect05.xlsx")
 
     def test_create_file(self):
         """Test the a simple XlsxWriter file with worksheet protection."""
@@ -27,19 +26,19 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        unlocked = workbook.add_format({'locked': 0, 'hidden': 0})
-        hidden = workbook.add_format({'locked': 0, 'hidden': 1})
+        unlocked = workbook.add_format({"locked": 0, "hidden": 0})
+        hidden = workbook.add_format({"locked": 0, "hidden": 1})
 
         worksheet.protect()
 
-        worksheet.unprotect_range('=A1')
-        worksheet.unprotect_range('$C$1:$C$3')
-        worksheet.unprotect_range('G4:I6', 'MyRange')
-        worksheet.unprotect_range('K7')
+        worksheet.unprotect_range("=A1")
+        worksheet.unprotect_range("$C$1:$C$3")
+        worksheet.unprotect_range("G4:I6", "MyRange")
+        worksheet.unprotect_range("K7")
 
-        worksheet.write('A1', 1)
-        worksheet.write('A2', 2, unlocked)
-        worksheet.write('A3', 3, hidden)
+        worksheet.write("A1", 1)
+        worksheet.write("A2", 2, unlocked)
+        worksheet.write("A3", 3, hidden)
 
         workbook.close()
 
