@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('quote_name04.xlsx')
+        self.set_filename("quote_name04.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -29,22 +28,20 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [1, 2, 3, 4, 5],
             [2, 4, 6, 8, 10],
             [3, 6, 9, 12, 15],
-
         ]
 
-        worksheet = workbook.add_worksheet('Sheet 1')
-        chart = workbook.add_chart({'type': 'pie'})
+        worksheet = workbook.add_worksheet("Sheet 1")
+        chart = workbook.add_chart({"type": "pie"})
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({'values': ['Sheet 1', 0, 0, 4, 0],
-                          'name': ['Sheet 1', 0, 0]})
+        chart.add_series({"values": ["Sheet 1", 0, 0, 4, 0], "name": ["Sheet 1", 0, 0]})
 
-        chart.set_title({'name': 'Foo'})
+        chart.set_title({"name": "Foo"})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
