@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('set_column07.xlsx')
+        self.set_filename("set_column07.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,9 +26,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        bold = workbook.add_format({'bold': 1})
-        italic = workbook.add_format({'italic': 1})
-        bold_italic = workbook.add_format({'bold': 1, 'italic': 1})
+        bold = workbook.add_format({"bold": 1})
+        italic = workbook.add_format({"italic": 1})
+        bold_italic = workbook.add_format({"bold": 1, "italic": 1})
 
         data = [
             [1, 2, 3, 4, 5],
@@ -37,18 +36,18 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [3, 6, 9, 12, 15],
         ]
 
-        worksheet.write('A1', 'Foo', italic)
-        worksheet.write('B1', 'Bar', bold)
-        worksheet.write_column('A2', data[0])
-        worksheet.write_column('B2', data[1])
-        worksheet.write_column('C2', data[2])
+        worksheet.write("A1", "Foo", italic)
+        worksheet.write("B1", "Bar", bold)
+        worksheet.write_column("A2", data[0])
+        worksheet.write_column("B2", data[1])
+        worksheet.write_column("C2", data[2])
 
         worksheet.set_row(12, None, italic)
-        worksheet.set_column('F:F', None, bold)
+        worksheet.set_column("F:F", None, bold)
 
-        worksheet.write('F13', None, bold_italic)
+        worksheet.write("F13", None, bold_italic)
 
-        worksheet.insert_image('E12', self.image_dir + 'logo.png')
+        worksheet.insert_image("E12", self.image_dir + "logo.png")
 
         workbook.close()
 
