@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2019, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('set_row03.xlsx')
+        self.set_filename("set_row03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -38,7 +37,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet.set_row(14, 11.25)
 
         worksheet.set_row(18, 14.25)
-        worksheet.set_row(20, 15.75, None, {'hidden': True})
+        worksheet.set_row(20, 15.75, None, {"hidden": True})
         worksheet.set_row(21, 16.50)
 
         workbook.close()
