@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,10 +17,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("set_start_page01.xlsx")
 
-        self.set_filename('set_start_page01.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
+        self.ignore_elements = {"xl/worksheets/sheet1.xml": ["<pageMargins"]}
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with printer settings."""
@@ -34,7 +33,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet.vertical_dpi = 200
 
-        worksheet.write('A1', 'Foo')
+        worksheet.write("A1", "Foo")
 
         workbook.close()
 
