@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('table04.xlsx')
+        self.set_filename("table04.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with tables."""
@@ -30,15 +29,15 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_column('C:F', 10.288)
+        worksheet.set_column("C:F", 10.288)
 
-        worksheet.add_table('C3:F13')
+        worksheet.add_table("C3:F13")
 
-        worksheet.write('A1', 'http://perl.com/')
+        worksheet.write("A1", "http://perl.com/")
 
-        worksheet.set_comments_author('John')
-        worksheet.write_comment('H1', 'Test1')
-        worksheet.write_comment('J1', 'Test2')
+        worksheet.set_comments_author("John")
+        worksheet.write_comment("H1", "Test1")
+        worksheet.write_comment("J1", "Test2")
 
         workbook.close()
 
