@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('table21.xlsx')
+        self.set_filename("table21.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with tables."""
@@ -27,12 +26,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write('A1', 'Column')
+        worksheet.write("A1", "Column")
 
-        worksheet.set_column('C:D', 10.288)
+        worksheet.set_column("C:D", 10.288)
 
-        worksheet.add_table('C3:D13',
-                            {'columns': [{'header': "Column"}]})
+        worksheet.add_table("C3:D13", {"columns": [{"header": "Column"}]})
 
         workbook.close()
 
