@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -17,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('textbox13.xlsx')
+        self.set_filename("textbox13.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with textbox(s)."""
@@ -27,11 +26,17 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_textbox('E9', 'This is some text',
-                                 {'line': {'color': 'red',
-                                           'width': 2,
-                                           'dash_type': 'round_dot',
-                                           }})
+        worksheet.insert_textbox(
+            "E9",
+            "This is some text",
+            {
+                "line": {
+                    "color": "red",
+                    "width": 2,
+                    "dash_type": "round_dot",
+                }
+            },
+        )
 
         workbook.close()
 
