@@ -3,7 +3,7 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
@@ -16,22 +16,16 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('utf8_06.xlsx')
+        self.set_filename("utf8_04.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
 
         workbook = Workbook(self.got_filename)
 
-        worksheet = workbook.add_worksheet()
+        worksheet = workbook.add_worksheet("Café & Café")
 
-        bold = workbook.add_format({'bold': 1})
-        italic = workbook.add_format({'italic': 1})
-
-        worksheet.write('A1', 'Foo', bold)
-        worksheet.write('A2', 'Bar', italic)
-        worksheet.write_rich_string('A3', 'Caf', bold, 'é')
+        worksheet.write("A1", "Café & Café")
 
         workbook.close()
 
